========
Contents
========

.. toctree::
   :numbered:


   readme
   cli_reference
   config_schema
   api_reference/index
   contributing
   authors
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
